Subject: linux-next: manual merge of the block tree with Linus' tree

From: Stephen Rothwell <[email-masked]>
Date: Wed, 3 Jun 2015 13:33:22 +1000

Hi Jens,

Today's linux-next merge of the block tree got a conflict in
mm/page-writeback.c between commit 464d1387acb9 ("writeback: use |1
instead of +1 to protect against div by zero") from Linus' tree and
commit de1fff37b278 ("writeback: s/bdi/wb/ in mm/page-writeback.c")
from the block tree.

I fixed it up (see below) and can carry the fix as necessary (no action
is required).

-- 
Cheers,
Stephen Rothwell                    [email-masked]

diff --cc mm/page-writeback.c
index eb59f7eea508,e1514d5b4e9b..000000000000
--- a/mm/page-writeback.c
+++ b/mm/page-writeback.c
@@@ -802,27 -990,27 +990,27 @@@ static void wb_position_ratio(struct di
  	 * threshold, so that the occasional writes won't be blocked and active
  	 * writes can rampup the threshold quickly.
  	 */
- 	bdi_thresh = max(bdi_thresh, (limit - dirty) / 8);
+ 	wb_thresh = max(wb_thresh, (limit - dtc->dirty) / 8);
  	/*
- 	 * scale global setpoint to bdi's:
- 	 *	bdi_setpoint = setpoint * bdi_thresh / thresh
+ 	 * scale global setpoint to wb's:
+ 	 *	wb_setpoint = setpoint * wb_thresh / thresh
  	 */
- 	x = div_u64((u64)bdi_thresh << 16, thresh | 1);
- 	bdi_setpoint = setpoint * (u64)x >> 16;
 -	x = div_u64((u64)wb_thresh << 16, dtc->thresh + 1);
++	x = div_u64((u64)wb_thresh << 16, dtc->thresh | 1);
+ 	wb_setpoint = setpoint * (u64)x >> 16;
  	/*
  	 * Use span=(8*write_bw) in single bdi case as indicated by
  	 * (thresh - bdi_thresh ~= 0) and transit to bdi_thresh in JBOD case.
  	 *
- 	 *        bdi_thresh                    thresh - bdi_thresh
- 	 * span = ---------- * (8 * write_bw) + ------------------- * bdi_thresh
- 	 *          thresh                            thresh
+ 	 *        wb_thresh                    thresh - wb_thresh
+ 	 * span = --------- * (8 * write_bw) + ------------------ * wb_thresh
+ 	 *         thresh                           thresh
  	 */
- 	span = (thresh - bdi_thresh + 8 * write_bw) * (u64)x >> 16;
- 	x_intercept = bdi_setpoint + span;
+ 	span = (dtc->thresh - wb_thresh + 8 * write_bw) * (u64)x >> 16;
+ 	x_intercept = wb_setpoint + span;
  
- 	if (bdi_dirty < x_intercept - span / 4) {
- 		pos_ratio = div64_u64(pos_ratio * (x_intercept - bdi_dirty),
- 				      (x_intercept - bdi_setpoint) | 1);
+ 	if (dtc->wb_dirty < x_intercept - span / 4) {
+ 		pos_ratio = div64_u64(pos_ratio * (x_intercept - dtc->wb_dirty),
 -				      x_intercept - wb_setpoint + 1);
++				      (x_intercept - wb_setpoint) | 1);
  	} else
  		pos_ratio /= 4;
@@@ -802,27 -990,27 +990,27 @@@ static void wb_position_ratio(struct di
  	/*
- 	 * Use span=(8*write_bw) in single bdi case as indicated by
- 	 * (thresh - bdi_thresh ~= 0) and transit to bdi_thresh in JBOD case.
+ 	 * Use span=(8*write_bw) in single wb case as indicated by
+ 	 * (thresh - wb_thresh ~= 0) and transit to wb_thresh in JBOD case.
  	 *